@@ -1,6 +1,8 @@
 package FLTK;
+use strict;
+use warnings;
 use Fl qw[:all];
-our $VERSION = '0.99.13';
+our $VERSION = '0.99.14';
 BEGIN {*FLTK:: = *Fl::}
 1;
 __END__
